@@ -4,6 +4,7 @@ from typing import Any, ClassVar
 
 from hud.adapters.common import CLA, Adapter
 from hud.adapters.common.types import (
+    CLAButton,
     CLAKey,
     ClickAction,
     DragAction,
@@ -27,6 +28,8 @@ class OperatorAdapter(Adapter):
         "arrowright": "right",
     }
 
+    BUTTON_MAP: ClassVar[dict[str, CLAButton]] = {"wheel": "middle"}
+
     def __init__(self) -> None:
         super().__init__()
         # OpenAI Computer Use default dimensions
@@ -45,6 +48,7 @@ class OperatorAdapter(Adapter):
             if action_type == "click":
                 x, y = data.get("x", 0), data.get("y", 0)
                 button = data.get("button", "left")
+                button = self.BUTTON_MAP.get(button, button)
                 return ClickAction(point=Point(x=x, y=y), button=button)
 
             elif action_type == "double_click":
